==> deepin-camera_6.5.23.tar.xz: BUILD/src/translations/deepin-camera_nb.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>CMainWindow</name>
    <message>
        <location filename="../src/mainwindow.cpp" line="1181"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1460"/>
        <source>Photo</source>
        <translation>Foto</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1469"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1901"/>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Videoopptagning er i gang. Lukk vinduet?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="2034"/>
        <source>Switch Cameras</source>
        <translation>Bytt kamera</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="2128"/>
        <source>Settings</source>
        <translation>Innstillinger</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <location filename="../src/closedialog.cpp" line="26"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../src/closedialog.cpp" line="26"/>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <location filename="../src/imageitem.cpp" line="66"/>
        <source>Copy</source>
        <translation>Kopier</translation>
    </message>
    <message>
        <location filename="../src/imageitem.cpp" line="70"/>
        <source>Delete</source>
        <translation>Slett</translation>
    </message>
    <message>
        <location filename="../src/imageitem.cpp" line="74"/>
        <source>Open folder</source>
        <translation>Åpne mappe</translation>
    </message>
    <message>
        <location filename="../src/imageitem.cpp" line="77"/>
        <source>Print</source>
        <translation>Skriv ut</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="213"/>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="229"/>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera er et verktøy for å ta bilder og videoer ved hjelp av PC-kameraet eller webkameraen din.</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="16"/>
        <source>OptionPicLineEditBtn</source>
        <translation>OptionPicLineEditBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="17"/>
        <source>OptionVideoLineEditBtn</source>
        <translation>OptionVideoLineEditBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="18"/>
        <source>OptionFormatLabel</source>
        <translation>OptionFormatLabel</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="19"/>
        <source>OptionFrame</source>
        <translation>OptionFrame</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="20"/>
        <source>PicOption</source>
        <translation>PicOption</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="21"/>
        <source>VideoOption</source>
        <translation>VideoOption</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="22"/>
        <source>OptionPicSelectableLineEdit</source>
        <translation>OptionPicSelectableLineEdit</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="23"/>
        <source>OptionVideoSelectableLineEdit</source>
        <translation>OptionVideoSelectableLineEdit</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="24"/>
        <source>OptionInvalidDialog</source>
        <translation>OptionInvalidDialog</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="25"/>
        <source>SettingDialog</source>
        <translation>SettingDialog</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="27"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="28"/>
        <source>TitleBar</source>
        <translation>TitleBar</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="29"/>
        <source>TitleMenu</source>
        <translation>TitleMenu</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="30"/>
        <source>VideoPreviewWidget</source>
        <translation>VideoPreviewWidget</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="33"/>
        <source>SelectBtn</source>
        <translation>SelectBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="34"/>
        <source>PicVdBtn</source>
        <translation>PicVdBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="35"/>
        <source>TakeVdEndBtn</source>
        <translation>Tage video slutt</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="36"/>
        <source>ThumbnailPreview</source>
        <translation>Miniaturforhåndsvisning</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="37"/>
        <source>ModeSwitchBox</source>
        <translation>Tilstandsskifteboks</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="38"/>
        <source>SwitchRecordBtn</source>
        <translation>Skift registreringsknapp</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="40"/>
        <source>LeftBtnsBox</source>
        <translation>Venstre knappboks</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="41"/>
        <source>UnfoldBtn</source>
        <translation>Utvid knapp</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="42"/>
        <source>FoldBtn</source>
        <translation>Falt knapp</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="43"/>
        <source>FlashlightUnfoldBtn</source>
        <translation>Lampeutvid knapp</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="44"/>
        <source>FlashlightFoldBtn</source>
        <translation>Lampefalt knapp</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="45"/>
        <source>FlashlightOnBtn</source>
        <translation>Lampe på knapp</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="46"/>
        <source>FlashlightOffBtn</source>
        <translation>Lampe av knapp</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="47"/>
        <source>DelayUnfoldBtn</source>
        <translation>Forsinkelseutvid knapp</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="48"/>
        <source>DelayFoldBtn</source>
        <translation>Forsinkelsefalt knapp</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="49"/>
        <source>DelayNoDelayBtn</source>
        <translation>Ingen forsinkelse knapp</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="50"/>
        <source>Delay3SecBtn</source>
        <translation>3 sekunder forsinkelse knapp</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="51"/>
        <source>Delay6SecBtn</source>
        <translation>6 sekunder forsinkelse knapp</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="52"/>
        <source>FiltersUnfoldBtn</source>
        <translation>Filterutvid knapp</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="53"/>
        <source>FiltersFoldBtn</source>
        <translation>Filterfalt knapp</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="54"/>
        <source>FiltersCloseBtn</source>
        <translation>Filterlukk knapp</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="55"/>
        <source>ExposureBtn</source>
        <translation>Utstråling</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="56"/>
        <source>ExposureSlider</source>
        <translation>Utstrålingssliser</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="59"/>
        <source>ShortcutCallMenu</source>
        <translation>Snarvei til meny</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="60"/>
        <source>ShortcutCopy</source>
        <translation>Kopier snarvei</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="61"/>
        <source>ShortcutDelete</source>
        <translation>Slett snarvei</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="62"/>
        <source>ShortcutOpenFolder</source>
        <translation>Åpne mappe snarvei</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="63"/>
        <source>ShortcutPrint</source>
        <translation>Skriv snarvei</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="66"/>
        <source>ViewShortCut</source>
        <translation>Vis snarvei</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="67"/>
        <source>SpaceShortCut</source>
        <translation>Plass snarvei</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="70"/>
        <source>CloseDlg</source>
        <translation>Lukk dialog</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="73"/>
        <source>PrintDialog</source>
        <translation>Skriv dialog</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="76"/>
        <source>CancelBtn</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="77"/>
        <source>CloseBtn</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="287"/>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Du har ikke tillatelse til å operere denne mappen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="289"/>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="361"/>
        <source>Open folder</source>
        <translation>Åpne mappe</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="909"/>
        <source>File not saved</source>
        <translation>Filen er ikke lagret</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="10"/>
        <source>Settings</source>
        <translation>Innstillinger</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="11"/>
        <source>Basic</source>
        <translation>Grunnleggende</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="12"/>
        <source>File location</source>
        <translation>Filstedet</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="13"/>
        <source>Photos:</source>
        <translation>Fotografi:</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="14"/>
        <source>Videos:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="15"/>
        <source>Gridlines</source>
        <translation>Rutemal</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="16"/>
        <source>1*1 lines</source>
        <translation>1*1 linjer</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="17"/>
        <source>2*2 lines</source>
        <translation>2*2 linjer</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="18"/>
        <source>Shoot</source>
        <translation>Ta</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="19"/>
        <source>Burst mode</source>
        <translation>Burst-modus</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="20"/>
        <source>Self-timer delay</source>
        <translation>Selv-timerforsinkelse</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="21"/>
        <source>Mirror mode</source>
        <translation>Speil-modus</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="22"/>
        <source>Flashlight</source>
        <translation>Lampe</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="23"/>
        <source>Output</source>
        <translation>Utdata</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="24"/>
        <source>Sound effects</source>
        <translation>Lyd-effekter</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="25"/>
        <source>Output format</source>
        <translation>Utdataformat</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="26"/>
        <source>Photo:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="27"/>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="28"/>
        <source>4 pcs</source>
        <translation>4 stk</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="29"/>
        <source>10 pcs</source>
        <translation>10 stk</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="30"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="31"/>
        <source>Resolution settings</source>
        <translation>Oppsløsningsinnstillinger</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="32"/>
        <source>Maximum resolution:</source>
        <translation>Maksimal oppsløsning:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../src/shortcut.cpp" line="14"/>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="15"/>
        <source>Settings</source>
        <translation>Innstillinger</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="16"/>
        <source>Stop recording</source>
        <translation>Stopp opptak</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="17"/>
        <source>Stop taking photos</source>
        <translation>Stopp bilder</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="18"/>
        <source>Context menu</source>
        <translation>Kontekst meny</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="19"/>
        <source>Copy</source>
        <translation>Kopier</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="20"/>
        <source>Delete</source>
        <translation>Slett</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="21"/>
        <source>Open</source>
        <translation>Åpne</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="22"/>
        <source>Print</source>
        <translation>Skriv ut</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="23"/>
        <source>Help</source>
        <translation>Hjelp</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="24"/>
        <source>Display shortcuts</source>
        <translation>Vis snarveier</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <location filename="../src/Settings.cpp" line="61"/>
        <source>mp4</source>
        <translation>mp4</translation>
    </message>
    <message>
        <location filename="../src/Settings.cpp" line="61"/>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <location filename="../src/Settings.cpp" line="191"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="254"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="260"/>
        <source>Vivid</source>
        <translation>Vivid</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="263"/>
        <source>Warm</source>
        <translation>Varm</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="266"/>
        <source>Cold</source>
        <translation>Kold</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="269"/>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="272"/>
        <source>Film</source>
        <translation>Film</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="275"/>
        <source>Gray</source>
        <translation>Grå</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="278"/>
        <source>B&amp;W</source>
        <translation>Svart og hvit</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="83"/>
        <source>Flashlight</source>
        <translation>Lampe</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="90"/>
        <source>On</source>
        <translation>På</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="97"/>
        <source>Off</source>
        <translation>Av</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="112"/>
        <source>Delay capture</source>
        <translation>Forsink opptak</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="119"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="142"/>
        <source>Filters</source>
        <translation>Filter</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="191"/>
        <source>Exposure</source>
        <translation>Utstråling</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <location filename="../src/videowidget.cpp" line="346"/>
        <source>No webcam found</source>
        <translation>Ingen kamera funnet</translation>
    </message>
    <message>
        <location filename="../src/videowidget.cpp" line="384"/>
        <source>The webcam is in use</source>
        <translation>Kameraet er i bruk</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.33.tar.xz: BUILD/src/translations/deepin-camera_nb.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Videoopptredet er i gang. Lukk vinduet?</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Innstillinger</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Foto</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Bytt kamera</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Kopier</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slett</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Åpne mappe</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Skriv ut</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Du har ikke tillatelse til å operere denne mappen</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Åpne mappe</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Innstillinger</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Grunnleggende</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Filsted</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Ta bilde</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Burst-modus</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Selv-timer forsinkelse</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Utdata</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Utdataformat</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 stk</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 stk</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera er et verktøy for oppfølging av bilder og videoer ved bruk av PC-kameraet eller webcam.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Fil ikke lagret</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Oppløsningsinnstillinger</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Fotografer:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Videos:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Lyd effekter</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Speilmodus</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Lampe</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Rutemønstre</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>1:1-linjer</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>2:2-linjer</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>Maksimal oppløsning:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Innstillinger</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Stopp opptak</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopier</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slett</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Åpne</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Skriv ut</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hjelp</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Vis snarveier</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Stopp med å ta bilder</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Kontekstmeny</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>mp4</source>
        <translation>mp4</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Vivid</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Varm</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Kold</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Films</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grå</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>Svart og hvit</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Lyktstav</translation>
    </message>
    <message>
        <source>On</source>
        <translation>På</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Av</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Forsinket opptak</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Utstråling</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Ingen webkamera funnet</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Webkameraen er i bruk</translation>
    </message>
</context>
</TS>
